@@ -19,10 +19,12 @@ import shutil
 import subprocess
 import requests
 import sys
+import socket
 from typing import List
 
 import boto3
 import tldextract
+import nmap
 
 from .logger import get_logger
 from .client import get_secret
@@ -41,9 +43,11 @@ class LetsEncrypt:
 
     def _validate_device_connection(self, hostname, timeout=5):
         try:
-            _ = requests.head(
-                'https://{host}'.format(host=hostname), timeout=timeout, verify=False)
-            _ = self._register_lets_encrypt_account()
+            # Validate Device is Up
+            scanner = nmap.PortScanner()
+            ip_address = socket.gethostbyname(hostname)
+            scanner.scan(ip_address, '1', '-v')
+            self._register_lets_encrypt_account()
             return hostname
         except requests.ConnectionError:
             raise Exception(
@@ -116,11 +120,9 @@ class LetsEncrypt:
         subdomain = tldextract.extract(
             self.hostname).subdomain
         subprocess.call(
-            '{directory}/acme.sh/acme.sh --upgrade'.format(directory=os.getenv('HOME')))
-        subprocess.call(
-            '{directory}/acme.sh/acme.sh --set-default-chain  --preferred-chain isrg  --server letsencrypt')
-        subprocess.call('{directory}/acme.sh/acme.sh --signcsr --csr {csr} --dns dns_aws --challenge-alias {domain_validation} --force'.format(
-            directory=os.getenv('HOME'), csr=f'{csr}', domain_validation=f'{subdomain}.{self.subdelegate}'))
+            '{directory}/acme.sh/acme.sh --upgrade'.format(directory=os.getenv('HOME')), shell=True)
+        subprocess.call('/bin/bash {directory}/acme.sh/acme.sh --set-default-ca --server letsencrypt --preferred-chain "ISRG" --signcsr --csr {csr} --dns dns_aws --challenge-alias {domain_validation} --force'.format(
+            directory=os.getenv('HOME'), csr=f'{csr}', domain_validation=f'{subdomain}.{self.subdelegate}'), shell=True)
 
     def acme_local(self, csr: str) -> None:  # pragma: no cover
         subdomain = tldextract.extract(
@@ -130,16 +132,6 @@ class LetsEncrypt:
         subprocess.call('{directory}/.acme.sh/acme.sh --set-default-ca --test --signcsr --csr {csr} --dns dns_aws --challenge-alias {domain_validation} --preferred-chain "Fake LE Root X2" --force'.format(
             directory=os.getenv('HOME'), csr=f'{csr}', domain_validation=f'{subdomain}.{self.subdelegate}'), shell=True)
 
-    def acme_test(self, csr: str) -> None:  # pragma: no cover
-        subdomain = tldextract.extract(
-            self.hostname).subdomain
-        subprocess.call(
-            '{directory}/.acme.sh/acme.sh --upgrade'.format(directory=os.getenv('HOME')), shell=True)
-        subprocess.call(
-            '{directory}/.acme.sh/acme.sh --set-default-chain  --preferred-chain isrg  --server letsencrypt', shell=True)
-        subprocess.call('{directory}/acme.sh/acme.sh --signcsr --csr {csr} --dns dns_aws --challenge-alias {domain_validation} --force'.format(
-            directory=os.getenv('HOME'), csr=f'{csr}', domain_validation=f'{subdomain}.{self.subdelegate}'), shell=True)
-
     def acme_private_ca_local(self, csr: str, acme_server_url: str) -> None:  # pragma: no cover
         prefix = os.environ['PREFIX']
         root_certificate = get_secret(
